@@ -1,5 +1,7 @@
 package POEx::Role::SessionInstantiation::Meta::POEState;
-$POEx::Role::SessionInstantiation::Meta::POEState::VERSION = '1.100920';
+BEGIN {
+  $POEx::Role::SessionInstantiation::Meta::POEState::VERSION = '1.102610';
+}
 
 use MooseX::Declare;
 
@@ -25,8 +27,7 @@ class POEx::Role::SessionInstantiation::Meta::POEState
     has from    => ( is => 'ro', isa => Maybe[Str] );
 
 
-    method clone
-    {
+    method clone {
         return $self->meta->clone_object($self);
     }
 }
@@ -43,7 +44,7 @@ POEx::Role::SessionInstantiation::Meta::POEState - A read-only object that provi
 
 =head1 VERSION
 
-version 1.100920
+version 1.102610
 
 =head1 PUBLIC_ATTRIBUTES
 
@@ -86,7 +87,7 @@ Clones the current POEState object and returns it
 
 =head1 AUTHOR
 
-  Nicholas Perez <nperez@cpan.org>
+Nicholas Perez <nperez@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
