@@ -1,8 +1,6 @@
-{package MyTrait;}
 use MooseX::Declare;
 
-role MyTrait(Str :$attr = 'blarg')
-{
+role MyTrait(Str :$attr = 'blarg') {
     use Test::More;
     use aliased 'POEx::Role::Event';
     use MooseX::Types::Moose('Int');
@@ -11,8 +9,7 @@ role MyTrait(Str :$attr = 'blarg')
 
     has $attr => ( is => 'rw', isa => Int );
 
-    after _start is Event
-    {
+    after _start is Event {
         $self->$attr(1);
         pass("Trait start called and attribute($attr) set");
     }
